==> max3263x-0.2.0.crate: max3263x-0.2.0/src/usb/cn.rs <==
#[doc = "Register `CN` reader"]
pub struct R(crate::R<CN_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CN_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CN_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CN_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CN` writer"]
pub struct W(crate::W<CN_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CN_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CN_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CN_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `usb_en` reader - USB Device Interface Enable"]
pub struct USB_EN_R(crate::FieldReader<bool, bool>);
impl USB_EN_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        USB_EN_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for USB_EN_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `usb_en` writer - USB Device Interface Enable"]
pub struct USB_EN_W<'a> {
    w: &'a mut W,
}
impl<'a> USB_EN_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - USB Device Interface Enable"]
    #[inline(always)]
    pub fn usb_en(&self) -> USB_EN_R {
        USB_EN_R::new((self.bits & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - USB Device Interface Enable"]
    #[inline(always)]
    pub fn usb_en(&mut self) -> USB_EN_W {
        USB_EN_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "USB Control Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cn](index.html) module"]
pub struct CN_SPEC;
impl crate::RegisterSpec for CN_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [cn::R](R) reader structure"]
impl crate::Readable for CN_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [cn::W](W) writer structure"]
impl crate::Writable for CN_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CN to value 0"]
impl crate::Resettable for CN_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> max3263x-0.4.0.crate: max3263x-0.4.0/src/usb/cn.rs <==
#[doc = "Register `CN` reader"]
pub struct R(crate::R<CN_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CN_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CN_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CN_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CN` writer"]
pub struct W(crate::W<CN_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CN_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CN_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CN_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `usb_en` reader - USB Device Interface Enable"]
pub struct USB_EN_R(crate::FieldReader<bool>);
impl USB_EN_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        USB_EN_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for USB_EN_R {
    type Target = crate::FieldReader<bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `usb_en` writer - USB Device Interface Enable"]
pub struct USB_EN_W<'a> {
    w: &'a mut W,
}
impl<'a> USB_EN_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - USB Device Interface Enable"]
    #[inline(always)]
    pub fn usb_en(&self) -> USB_EN_R {
        USB_EN_R::new((self.bits & 1) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - USB Device Interface Enable"]
    #[inline(always)]
    pub fn usb_en(&mut self) -> USB_EN_W {
        USB_EN_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "USB Control Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cn](index.html) module"]
pub struct CN_SPEC;
impl crate::RegisterSpec for CN_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [cn::R](R) reader structure"]
impl crate::Readable for CN_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [cn::W](W) writer structure"]
impl crate::Writable for CN_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CN to value 0"]
impl crate::Resettable for CN_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
